@@ -43,7 +43,7 @@ class PexInfo(object):
     from .interpreter import PythonInterpreter
     from pkg_resources import get_platform
 
-    pi = PythonInterpreter()
+    pi = PythonInterpreter.get()
     return {
       'class': pi.identity.interpreter,
       'version': pi.identity.version,
@@ -58,7 +58,7 @@ class PexInfo(object):
       'always_write_cache': False,
       'build_properties': cls.make_build_properties(),
     }
-    return cls(json.dumps(pex_info))
+    return cls(info=pex_info)
 
   @classmethod
   def from_pex(cls, pex):
@@ -68,17 +68,24 @@ class PexInfo(object):
     else:
       with open(os.path.join(pex, cls.PATH)) as fp:
         pex_info = fp.read()
-    return cls(pex_info)
+    return cls.from_json(pex_info)
+
+  @classmethod
+  def from_json(cls, content):
+    if isinstance(content, bytes):
+      content = content.decode('utf-8')
+    return PexInfo(info=json.loads(content))
 
   @classmethod
   def debug(cls, msg):
     if 'PEX_VERBOSE' in os.environ:
       print('PEX: %s' % msg, file=sys.stderr)
 
-  def __init__(self, content=json.dumps({})):
-    if isinstance(content, bytes):
-      content = content.decode('utf-8')
-    self._pex_info = json.loads(content)
+  def __init__(self, info=None):
+    if info is not None and not isinstance(info, dict):
+      raise ValueError('PexInfo can only be seeded with a dict, got: '
+                       '%s of type %s' % (info, type(info)))
+    self._pex_info = info or {}
     self._distributions = self._pex_info.get('distributions', {})
     self._requirements = OrderedSet(
         PexRequirement(*req) for req in self._pex_info.get('requirements', []))
@@ -202,3 +209,6 @@ class PexInfo(object):
     pex_info_copy = self._pex_info.copy()
     pex_info_copy['requirements'] = list(self._requirements)
     return json.dumps(pex_info_copy)
+
+  def copy(self):
+    return PexInfo(info=self._pex_info.copy())
